@@ -11,6 +11,7 @@ from multithread import multithread_engine
 from get_property import get_template_directory
 from get_property import get_updated_list
 from get_property import get_syntax
+from get_property import get_sorted_juniper_template_list 
 import re
 import initialize
 
@@ -51,6 +52,12 @@ def auditdiff_engine(template_list,node_object,auditcreeper,output,remediation):
 	### CISCO WILL REQUIRE BACKUP-CONFIGS (GET_CONFIG)
 	for index in initialize.element:
 
+		if(node_object[index]['platform'] == 'juniper'):
+
+			### THIS WILL RETURN A SORTED JUNIPER TEMPLATE LIST BASED ON JUNIPER'S 'SHOW CONFIGURATION' OUTPUT
+			template_list = get_sorted_juniper_template_list(template_list)
+#			print("TEMPLATE_LIST FIRST PHASE: {}".format(template_list))
+
 		for template in template_list:
 
 			### THIS SECTION OF CODE WILL PROCESS THE TEMPLATE AND OUTPUT TO A *.CONF FILE
@@ -141,8 +148,11 @@ def auditdiff_engine(template_list,node_object,auditcreeper,output,remediation):
 			print ("{}".format(node_object[index]['hostname']))
 
 		###UN-COMMENT THE BELOW PRINT STATEMENT FOR DEBUGING PURPOSES
-#		print("TEMPLATE_LIST: {}".format(template_list))
 		template_list_juniper = template_list[:]
+		if(node_object[index]['platform'] == 'juniper'):
+
+			### THIS WILL RETURN A SORTED JUNIPER TEMPLATE LIST BASED ON JUNIPER'S 'SHOW CONFIGURATION' OUTPUT
+			template_list = get_sorted_juniper_template_list(template_list)
 
 		### THIS WILL LOOP THROUGH ALL THE TEMPLATES SPECIFIED FOR THE PARTICULAR HOST IN NODES.YAML
 		for template in template_list:
@@ -369,6 +379,7 @@ def juniper_audit_diff(directory,template,template_list,diff_config,edit_list,se
 
 	index_of_template_list = template_list.index(template) + 1
 
+
 	###UN-COMMENT THE BELOW PRINT STATEMENT FOR DEBUGING PURPOSES
 #	print("EDIT_LIST: {}".format(edit_list))
 
